summaryrefslogtreecommitdiffstats
path: root/ksysv/kscroller.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:45:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:45:05 -0600
commitd1248617107f659af9d03cf1ef6d783571a0cba8 (patch)
tree06ce6d250704f2cddca023e81b63f25b19c9aa48 /ksysv/kscroller.h
parent72fee035e994371467475e062b46287d68fa3f57 (diff)
downloadtdeadmin-d1248617107f659af9d03cf1ef6d783571a0cba8.tar.gz
tdeadmin-d1248617107f659af9d03cf1ef6d783571a0cba8.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'ksysv/kscroller.h')
-rw-r--r--ksysv/kscroller.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/ksysv/kscroller.h b/ksysv/kscroller.h
index 77a78f9..5b63346 100644
--- a/ksysv/kscroller.h
+++ b/ksysv/kscroller.h
@@ -70,7 +70,7 @@ public slots:
void setCornerWidget (TQWidget* corner);
/**
* Update the scrollbars. Call whenever you change the contents tqminimumSize.
*/
void updateScrollBars ();
@@ -83,12 +83,12 @@ protected:
/**
* Reimplemented for internal reasons, the API is not affected.
*/
- virtual TQSize tqsizeHint() const;
+ virtual TQSize sizeHint() const;
/**
* Reimplemented for internal reasons, the API is not affected.
*/
- virtual TQSize tqminimumSizeHint() const;
+ virtual TQSize minimumSizeHint() const;
private slots:
@@ -70,7 +70,7 @@ public slots:
void setCornerWidget (TQWidget* corner);
/**
- * Update the scrollbars. Call whenever you change the contents tqminimumSize.
+ * Update the scrollbars. Call whenever you change the contents minimumSize.
*/
void updateScrollBars ();